cv.partition: the function mimic the cvpartition in MATLAB

Description Usage Arguments Value

View source: R/cv.R

Description

the function mimic the cvpartition in MATLAB

Usage

1

Arguments

n

sample size

K

the number of cv folders

Value

a list of the follow elements

training

a list of K elements. Each element is a vector of indices of samples for training

test

a list of K elements. Each element is a vector of indices of samples for test

num.test.sets

an integer signifying the number of test sets


linulysses/mcfda documentation built on Jan. 17, 2021, 8:53 a.m.